NoEvents

Struct NoEvents 

pub struct NoEvents;
Provides a no-op implementation of RtcEvents which can be used in situations that do not require logging or otherwise doing anything in response to the events defined as part of RtcEvents.